* PUBH 6400 ;
* program02.sas ;
* Reading in data;

*---------------------------------------------------------------------------*
  Reading data from an external file.  If the data exist in an external
  text file rather than in the program you simply need to replace the
  DATALINES option on the INFILE statement with the directory path and
  filename of the file in quotes. A dump of an excel file will include
  names as the first row of the data. This row can be skipped by using
  the FIRSTOBS option.
  
  Contents of file bp.csv 

clinic,dbp6,sbp6,dbpbl,sbpbl
C,84,138,93,143
D,89,150,91,140
A,78,116,100,162
A,,,86,155
C,81,145,86,140
*---------------------------------------------------------------------------*;

DATA bp;
 INFILE '~/SAS_Files/bp.csv' DSD FIRSTOBS=2;
 INPUT clinic $  dbp6  sbp6  dbpbl  sbpbl ;
PROC PRINT DATA=bp;
TITLE 'Reading in Data from an External File';
RUN;

*---------------------------------------------------------------------------*
 You can also use the IMPORT procedure to read in data. The following code
 will read the file listed under DATAFILE and create a SAS dataset called
 bp. The GETNAMES option uses the first row of the data for variable names.
 PROC CONTENTS lists the names and attributes of variables on the SAS dataset
*---------------------------------------------------------------------------*;

PROC IMPORT DATAFILE= '~/SAS_Files/bp.csv'
            OUT = bp
	    DBMS = csv
	    REPLACE ;
	    GETNAMES=yes;
	    GUESSINGROWS = 9999;
PROC PRINT DATA=bp;
TITLE 'Reading in Data Using PROC IMPORT';
RUN;
PROC CONTENTS DATA=bp ;
RUN;

*---------------------------------------------------------------------------*
 If data on record is past the position 256 you need to increase the logical 
 record length (LRECL) to a larger value to read the data in correctly. 
 OBS option limits number of observation read in
*---------------------------------------------------------------------------;
DATA temp;
 INFILE '~/SAS_Files/tomhs.data' LRECL=500 OBS=6;
 INPUT @260 jntpain 2. ;
PROC PRINT DATA=temp;
TITLE 'Data read in correctly using LRECL option';
RUN;

*---------------------------------------------------------------------------*
  Reading special data with data in fixed positions. Special data includes
  dates or numbers with commas. Also needed to read in      
  character variables longer than 8 characters. Informats end with a period.
*---------------------------------------------------------------------------*;

DATA info;
   INFILE DATALINES ;
   INPUT @1  ssn $11. 
         @13 taxdate mmddyy10. 
         @25 income : comma6. ;
DATALINES;
086-59-9054 04/12/2001 59,365
405-65-0987 03/05/2002 26,925
212-44-9054 04/15/2003 44,999
;
PROC PRINT DATA=info;
   VAR ssn taxdate income ;
   FORMAT taxdate mmddyy10.;
TITLE 'Reading in and Displaying Variables With Special Formats';
RUN;
*---------------------------------------------------------------------------*
  Using colon mofifier with List-directed data. Used when reading in
  special data like dates or numbers with commas. Also needed to read in      
  character variables longer than 8 characters. Informats end with a period.
*---------------------------------------------------------------------------*;

DATA info;
   INFILE DATALINES DLM=';';
   INPUT ssn : $11. taxdate : mmddyy10. income : comma6. ;
   DATALINES;
086-59-9054;04/12/2001;59,365
405-65-0987;03/05/2002;26,925
212-44-9054;04/15/2003;44,999
;
PROC PRINT DATA=taxinfo;
   VAR ssn taxdate income ;
   FORMAT taxdate mmddyy10.;
TITLE 'Reading in and Displaying Variables With Special Formats';
RUN;
