* PUBH 6400 ;
* program03.sas ;
* Descriptive procedures, plotting;

DATA weight;
 INFILE '~/SAS_Files/tomhs.data';
 INPUT @1 ptid $10. @12 clinic $1. @25 group 1. @30 sex $1.
       @58 height 4.0 @85 weight 5.0
       @115 sbpbl 3. @123 sbp12 3.; 

 bmi = (weight*703.0768)/(height*height);
 sbpchg = sbp12 - sbpbl;
 if group = 6 then active = 2; else active = 1;
RUN;

PROC PRINT DATA = weight (OBS=5) NOBS ;
TITLE 'Proc Print: Five observations from the TOMHS Study';
RUN;

PROC MEANS DATA = weight ;
 VAR  height weight bmi;
 TITLE 'Proc Means Example 1';
RUN;

* MAXDEL option limits number of decimal places displayed;
PROC MEANS DATA = weight MEAN MEDIAN STD MAXDEC=2 ;
 VAR  height weight bmi;
 TITLE 'Proc Means Example 2 (specifying options)';
RUN;

PROC MEANS DATA = weight N MEAN STD MAXDEC=2 ;
 CLASS clinic;
 VAR height weight bmi ;
 TITLE 'Proc Means Example 3 (Using a CLASS statement)';
RUN;

PROC TTEST DATA = weight ; 
 VAR sbpchg;
 CLASS active;
 TITLE 'T-Test Comparing Active and Placebo Groups';
RUN;

PROC UNIVARIATE DATA = weight PLOT  ;
 ID ptid;
 VAR bmi;
 TITLE 'Proc Univariate Example 1';
RUN;

*---------------------------------------------------------------------------*
  With the Output Delivery System (ODS) you can selectively include portions
  of the output to go to the output window, thus reducing the amount of output
  generated. Each piece of output has a name that can be selected.
*---------------------------------------------------------------------------*;

*ODS TRACE ON/LISTING; * Lists the names of the pieces of output;
ODS SELECT BasicMeasures Quantiles; 
PROC UNIVARIATE DATA = weight ;
 ID ptid;
 VAR bmi;
 TITLE 'Proc Univariate Selecting Only the Basic Measures and Quantiles';
RUN;

*---------------------------------------------------------------------------*
  High resolution graphs can also be produced.
  The HISTOGRAM statement produces a high resolution histogram. The
  PROBPLOT statement creates a high resolution normal probability plot.
  The INSET statement inserts summary statistics as part of the histogram.
*---------------------------------------------------------------------------*;
  
ODS GRAPHICS ON;;
PROC UNIVARIATE DATA = weight NOPRINT;
 VAR bmi;
 HISTOGRAM bmi / NORMAL MIDPOINTS=20 to 40 by 2;
 INSET N    = 'N' (5.0)
       MEAN = 'Mean' (5.1)
       STD  = 'Sdev' (5.1)
       MIN  = 'Min'  (5.1)
       MAX  = 'Max'  (5.1)/ POS=NW HEADER='Summary Statistics';
 LABEL bmi = 'Body Mass Index (kg/m2)';
 TITLE 'Histogram and Normal Plot of BMI';
 PROBPLOT bmi/NORMAL (MU=est SIGMA=est);
RUN;

PROC SGPLOT;
 VBOX bmi;
 TITLE 'Boxplot of BMI';
RUN;

PROC SGPLOT;
 HBOX bmi/CATEGORY=sex;
 TITLE "Boxplot of BMI for Men and Women";
RUN;
