* PUBH 6400 ;
* program10.sas ;
* Creating permanent SAS datasets;

* This datastep will create a SAS dataset called sescore stored 
  in the directory pointed to by mylib. ;

LIBNAME mylib '.'; 
DATA mylib.sescore; * Permanent SAS datasets are referenced by 2-part names;
 INFILE '~/SAS_Files/tomhs.data' LRECL=400;
 INPUT
  @  1      ptid           $6.   @ 12     clinic         $1.
  @ 14      randdate  mmddyy10.  @ 25     group          1.  
  @ 49      educ           1.    @ 85     wtbl           5.1
  @ 97      wt12           5.1   @115     sbpbl          3.0
  @123      sbp12          3.0
  @236     (sebl_1-sebl_20) (1. +1)
  @276     (se12_1-se12_20) (1. +1) ;

wtd12    = wt12 - wtbl;
sbpd12   = sbp12 - sbpbl;
sescrbl  = MEAN (OF sebl_1-sebl_20) ;
sescr12  = MEAN (OF se12_1-se12_20) ;
sescrd12 = sescr12 - sescrbl ;

LABEL ptid     = 'Patient ID';
LABEL clinic   = 'Clinical Center';
LABEL randdate = 'Randomization Date';
LABEL educ     = 'Highest Education Level';
LABEL wt12     = 'Weight (lbs) at 12 Months';
LABEL wtbl     = 'Weight (lbs) at Baseine';
LABEL wtd12    = 'Weight Change at Baseline';
LABEL sbpbl    = 'Systolic BP (mmHg) at Baseline';
LABEL sbp12    = 'Systolic BP (mmHg) at 12 Months';
LABEL sbpd12   = 'Systolic BP Change at 12 Months';
LABEL group    = 'Treatment Group (1-6)';
LABEL sescrbl  = 'Side Efect at Baseline';
LABEL sescr12  = 'Side Efect at 12 Months';
LABEL sescrd12 = 'Side Efect Change Score';

FORMAT randdate mmddyy10. ;

DROP sebl_1 - sebl_20 se12_1 - se12_20 ;
* These variables won't be included in the dataset;
RUN;

PROC CONTENTS DATA=mylib.sescore POSITION;
TITLE 'Description of Variables in Dataset SESCORE' ;
RUN;
PROC PRINT DATA=mylib.sescore (OBS=10);
TITLE 'Listing of 10 Obs from Permanent SAS dataset' ;
RUN;
